use cuddle_ci::cuddle_file::CuddleFile;
use cuddle_ci::node_service::NodeService;
use cuddle_ci::rust_service::architecture::{Architecture, Os};
use cuddle_ci::CuddleCI;

#[tokio::main]
async fn main() -> eyre::Result<()> {
    dagger_sdk::connect(|client| async move {
        let cuddle_file = CuddleFile::from_cuddle_file().await?;

        let service = &NodeService::new(client.clone(), &cuddle_file.vars.service)
            .with_arch(Architecture::Amd64)
            .with_os(Os::Linux)
            .to_owned();

        CuddleCI::default()
            .with_pull_request(service)
            .with_main(service)
            .execute(std::env::args())
            .await?;

        Ok(())
    })
    .await?;

    Ok(())
}
